@@ -20,62 +20,33 @@
 
 #include <libdmapsharing/dmap-container-db.h>
 
-static gint dmap_container_db_init_count = 0;
-
 static void
-dmap_container_db_init (G_GNUC_UNUSED DMAPContainerDbIface * iface)
+dmap_container_db_default_init (DmapContainerDbInterface * iface)
 {
-	dmap_container_db_init_count++;
 }
 
-static void
-dmap_container_db_finalize (G_GNUC_UNUSED DMAPContainerDbIface * iface)
-{
-	dmap_container_db_init_count--;
-}
-
-/* FIXME: No G_DEFINE_INTERFACE available in GObject headers: */
-GType
-dmap_container_db_get_type (void)
-{
-	static GType object_type = 0;
-
-	if (!object_type) {
-		static const GTypeInfo object_info = {
-			class_size:     sizeof (DMAPContainerDbIface),
-			base_init:     (GBaseInitFunc) dmap_container_db_init,
-			base_finalize: (GBaseFinalizeFunc) dmap_container_db_finalize
-		};
-		object_type =
-			g_type_register_static (G_TYPE_INTERFACE,
-						"DMAPContainerDb",
-						&object_info, 0);
-		g_type_interface_add_prerequisite (object_type,
-						   G_TYPE_OBJECT);
-	}
-	return object_type;
-}
+G_DEFINE_INTERFACE(DmapContainerDb, dmap_container_db, G_TYPE_OBJECT)
 
 void
-dmap_container_db_add (DMAPContainerDb * db, DMAPContainerRecord *record)
+dmap_container_db_add (DmapContainerDb * db, DmapContainerRecord *record)
 {
 	return DMAP_CONTAINER_DB_GET_INTERFACE (db)->add (db, record);
 }
 
-DMAPContainerRecord *
-dmap_container_db_lookup_by_id (DMAPContainerDb * db, guint id)
+DmapContainerRecord *
+dmap_container_db_lookup_by_id (DmapContainerDb * db, guint id)
 {
 	return DMAP_CONTAINER_DB_GET_INTERFACE (db)->lookup_by_id (db, id);
 }
 
 void
-dmap_container_db_foreach (DMAPContainerDb * db, GHFunc func, gpointer data)
+dmap_container_db_foreach (DmapContainerDb * db, DmapIdContainerRecordFunc func, gpointer data)
 {
 	DMAP_CONTAINER_DB_GET_INTERFACE (db)->foreach (db, func, data);
 }
 
 gulong
-dmap_container_db_count (DMAPContainerDb * db)
+dmap_container_db_count (DmapContainerDb * db)
 {
 	return DMAP_CONTAINER_DB_GET_INTERFACE (db)->count (db);
 }
