@@ -1,5 +1,5 @@
 /*
- * DMAPGstMP3InputStream class: Open a URI using dmap_gst_mp3_input_stream_new ().
+ * DmapGstMP3InputStream class: Open a URI using dmap_gst_mp3_input_stream_new ().
  * Data is decoded using GStreamer and is then reencoded as an MP3
  * stream by the class's read operations.
  *
@@ -28,7 +28,7 @@
 
 #define GST_APP_MAX_BUFFERS 1024
 
-struct DMAPGstMP3InputStreamPrivate
+struct DmapGstMP3InputStreamPrivate
 {
 	GstElement *pipeline;
 	GstElement *src;
@@ -38,8 +38,12 @@ struct DMAPGstMP3InputStreamPrivate
 	GstElement *sink;
 };
 
+/* FIXME: See note in dmap-gst-input-stream.h */
+void dmap_gst_input_stream_new_buffer_cb (GstElement * element,
+					  DmapGstInputStream * stream);
+
 static void
-pad_added_cb (G_GNUC_UNUSED GstElement * element,
+pad_added_cb (GstElement * element,
               GstPad * pad,
               GstElement *convert)
 {
@@ -65,7 +69,7 @@ dmap_gst_mp3_input_stream_new (GInputStream * src_stream)
 {
 	GstStateChangeReturn sret;
 	GstState state;
-	DMAPGstMP3InputStream *stream = NULL;
+	DmapGstMP3InputStream *stream = NULL;
 
 	GstElement *pipeline = NULL;
 	GstElement *src = NULL;
@@ -138,7 +142,7 @@ dmap_gst_mp3_input_stream_new (GInputStream * src_stream)
 
 	g_signal_connect (decode, "pad-added", G_CALLBACK (pad_added_cb), convert);
 
-	/* FIXME: this technique is shared with dmapd-daap-share.c */
+	/* FIXME: this technique is shared with dmapd-dmap-av-share.c */
 	sret = gst_element_set_state (pipeline, GST_STATE_PLAYING);
 	if (GST_STATE_CHANGE_ASYNC == sret) {
 		if (GST_STATE_CHANGE_SUCCESS !=
@@ -195,30 +199,33 @@ done:
 }
 
 static void
-dmap_gst_mp3_input_stream_kill_pipeline (DMAPGstInputStream * stream)
+dmap_gst_mp3_input_stream_kill_pipeline (DmapGstInputStream * stream)
 {
-	DMAPGstMP3InputStream *mp3_stream =
+	DmapGstMP3InputStream *mp3_stream =
 		DMAP_GST_MP3_INPUT_STREAM (stream);
 
 	gst_element_set_state (mp3_stream->priv->pipeline, GST_STATE_NULL);
 	gst_object_unref (GST_OBJECT (mp3_stream->priv->pipeline));
 }
 
-G_DEFINE_TYPE_WITH_PRIVATE (DMAPGstMP3InputStream, dmap_gst_mp3_input_stream,
-                            DMAP_TYPE_GST_INPUT_STREAM);
+G_DEFINE_TYPE (DmapGstMP3InputStream, dmap_gst_mp3_input_stream,
+	       DMAP_TYPE_GST_INPUT_STREAM);
 
 static void
-dmap_gst_mp3_input_stream_class_init (DMAPGstMP3InputStreamClass * klass)
+dmap_gst_mp3_input_stream_class_init (DmapGstMP3InputStreamClass * klass)
 {
-	DMAPGstInputStreamClass *parent_class =
+	DmapGstInputStreamClass *parent_class =
 		DMAP_GST_INPUT_STREAM_CLASS (klass);
 
+	g_type_class_add_private (klass,
+				  sizeof (DmapGstMP3InputStreamPrivate));
+
 	parent_class->kill_pipeline = dmap_gst_mp3_input_stream_kill_pipeline;
 }
 
 static void
-dmap_gst_mp3_input_stream_init (DMAPGstMP3InputStream * stream)
+dmap_gst_mp3_input_stream_init (DmapGstMP3InputStream * stream)
 {
-	stream->priv = dmap_gst_mp3_input_stream_get_instance_private (stream);
+	stream->priv = DMAP_GST_MP3_INPUT_STREAM_GET_PRIVATE (stream);
 
 }
