@@ -1,5 +1,5 @@
 /*
- * DMAPGstQtInputStream class: Open a URI using dmap_gst_qt_input_stream_new ().
+ * DmapGstQtInputStream class: Open a URI using dmap_gst_qt_input_stream_new ().
  * Data is decoded using GStreamer and is then reencoded as a QuickTime video
  * stream by the class's read operations.
  *
@@ -28,7 +28,7 @@
 
 #define GST_APP_MAX_BUFFERS 1024
 
-struct DMAPGstQtInputStreamPrivate
+struct DmapGstQtInputStreamPrivate
 {
 	GstElement *pipeline;
 	GstElement *src;
@@ -41,7 +41,7 @@ struct DMAPGstQtInputStreamPrivate
 
 /* FIXME: See note in dmap-gst-input-stream.h */
 void dmap_gst_input_stream_new_buffer_cb (GstElement * element,
-					  DMAPGstInputStream * stream);
+					  DmapGstInputStream * stream);
 
 static void
 pad_added_cb (GstElement * element,
@@ -70,7 +70,7 @@ dmap_gst_qt_input_stream_new (GInputStream * src_stream)
 {
 	GstStateChangeReturn sret;
 	GstState state;
-	DMAPGstQtInputStream *stream = NULL;
+	DmapGstQtInputStream *stream = NULL;
 
 	GstElement *pipeline = NULL;
         GstElement *src = NULL;
@@ -144,7 +144,7 @@ dmap_gst_qt_input_stream_new (GInputStream * src_stream)
 
 	g_signal_connect (decode, "pad-added", G_CALLBACK (pad_added_cb), convert);
 
-	/* FIXME: this technique is shared with dmapd-daap-share.c */
+	/* FIXME: this technique is shared with dmapd-dmap-av-share.c */
 	sret = gst_element_set_state (pipeline, GST_STATE_PLAYING);
 	if (GST_STATE_CHANGE_ASYNC == sret) {
 		if (GST_STATE_CHANGE_SUCCESS !=
@@ -206,9 +206,9 @@ done:
 }
 
 static void
-dmap_gst_qt_input_stream_kill_pipeline (DMAPGstInputStream * stream)
+dmap_gst_qt_input_stream_kill_pipeline (DmapGstInputStream * stream)
 {
-	DMAPGstQtInputStream *qt_stream =
+	DmapGstQtInputStream *qt_stream =
 		DMAP_GST_QT_INPUT_STREAM (stream);
 
 	// FIXME: It seems that I need to send an EOS, because QuickTime writes
@@ -219,23 +219,23 @@ dmap_gst_qt_input_stream_kill_pipeline (DMAPGstInputStream * stream)
 	gst_object_unref (GST_OBJECT (qt_stream->priv->pipeline));
 }
 
-G_DEFINE_TYPE (DMAPGstQtInputStream, dmap_gst_qt_input_stream,
+G_DEFINE_TYPE (DmapGstQtInputStream, dmap_gst_qt_input_stream,
 	       DMAP_TYPE_GST_INPUT_STREAM);
 
 static void
-dmap_gst_qt_input_stream_class_init (DMAPGstQtInputStreamClass * klass)
+dmap_gst_qt_input_stream_class_init (DmapGstQtInputStreamClass * klass)
 {
-	DMAPGstInputStreamClass *parent_class =
+	DmapGstInputStreamClass *parent_class =
 		DMAP_GST_INPUT_STREAM_CLASS (klass);
 
 	g_type_class_add_private (klass,
-				  sizeof (DMAPGstQtInputStreamPrivate));
+				  sizeof (DmapGstQtInputStreamPrivate));
 
 	parent_class->kill_pipeline = dmap_gst_qt_input_stream_kill_pipeline;
 }
 
 static void
-dmap_gst_qt_input_stream_init (DMAPGstQtInputStream * stream)
+dmap_gst_qt_input_stream_init (DmapGstQtInputStream * stream)
 {
 	stream->priv = DMAP_GST_QT_INPUT_STREAM_GET_PRIVATE (stream);
 
