@@ -33,16 +33,18 @@
 #include <glib/gi18n.h>
 #include <glib-object.h>
 
+#ifdef HAVE_AVAHI_0_6
 #include <avahi-client/lookup.h>
 #include <avahi-client/publish.h>
+#endif
 #include <avahi-client/client.h>
 #include <avahi-common/error.h>
 #include <avahi-glib/glib-malloc.h>
 #include <avahi-glib/glib-watch.h>
 
-struct _DMAPMdnsBrowserPrivate
+struct _DmapMdnsBrowserPrivate
 {
-	DMAPMdnsBrowserServiceType service_type;
+	DmapMdnsServiceType service_type;
 	AvahiClient *client;
 	AvahiGLibPoll *poll;
 	AvahiServiceBrowser *service_browser;
@@ -57,11 +59,15 @@ enum
 	LAST_SIGNAL
 };
 
-static void dmap_mdns_browser_class_init (DMAPMdnsBrowserClass * klass);
-static void dmap_mdns_browser_init (DMAPMdnsBrowser * browser);
+#ifdef HAVE_AVAHI_0_5
+#define AVAHI_ADDRESS_STR_MAX (40)	/* IPv6 Max = 4*8 + 7 + 1 for NUL */
+#endif
+
+static void dmap_mdns_browser_class_init (DmapMdnsBrowserClass * klass);
+static void dmap_mdns_browser_init (DmapMdnsBrowser * browser);
 static void dmap_mdns_browser_dispose (GObject * object);
 static void dmap_mdns_browser_finalize (GObject * object);
-static void avahi_client_init (DMAPMdnsBrowser * browser);
+static void avahi_client_init (DmapMdnsBrowser * browser);
 static void resolve_cb (AvahiServiceResolver * service_resolver,
 			AvahiIfIndex interface,
 			AvahiProtocol protocol,
@@ -72,15 +78,17 @@ static void resolve_cb (AvahiServiceResolver * service_resolver,
 			const gchar * host_name,
 			const AvahiAddress * address,
 			uint16_t port, AvahiStringList * text,
+#ifdef HAVE_AVAHI_0_6
 			AvahiLookupResultFlags flags,
-			DMAPMdnsBrowser * browser);
-static gboolean dmap_mdns_browser_resolve (DMAPMdnsBrowser * browser,
+#endif
+			DmapMdnsBrowser * browser);
+static gboolean dmap_mdns_browser_resolve (DmapMdnsBrowser * browser,
 					   const gchar * name,
 					   const gchar * domain);
-static void browser_add_service (DMAPMdnsBrowser * browser,
+static void browser_add_service (DmapMdnsBrowser * browser,
 				 const gchar * service_name,
 				 const gchar * domain);
-static void browser_remove_service (DMAPMdnsBrowser * browser,
+static void browser_remove_service (DmapMdnsBrowser * browser,
 				    const gchar * service_name);
 static void browse_cb (AvahiServiceBrowser * service_browser,
 		       AvahiIfIndex interface,
@@ -88,13 +96,16 @@ static void browse_cb (AvahiServiceBrowser * service_browser,
 		       AvahiBrowserEvent event,
 		       const gchar * name,
 		       const gchar * type, const gchar * domain,
+#ifdef HAVE_AVAHI_0_6
 		       AvahiLookupResultFlags flags,
-		       DMAPMdnsBrowser * browser);
-static void free_service (DMAPMdnsBrowserService * service);
+#endif
+		       DmapMdnsBrowser * browser);
+
+#define DMAP_MDNS_BROWSER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_MDNS_BROWSER, DmapMdnsBrowserPrivate))
 
 static guint dmap_mdns_browser_signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE_WITH_PRIVATE (DMAPMdnsBrowser, dmap_mdns_browser, G_TYPE_OBJECT);
+G_DEFINE_TYPE (DmapMdnsBrowser, dmap_mdns_browser, G_TYPE_OBJECT);
 
 GQuark
 dmap_mdns_browser_error_quark (void)
@@ -109,7 +120,7 @@ dmap_mdns_browser_error_quark (void)
 }
 
 static void
-dmap_mdns_browser_class_init (DMAPMdnsBrowserClass * klass)
+dmap_mdns_browser_class_init (DmapMdnsBrowserClass * klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
@@ -118,52 +129,50 @@ dmap_mdns_browser_class_init (DMAPMdnsBrowserClass * klass)
 	object_class->dispose = dmap_mdns_browser_dispose;
 	object_class->finalize = dmap_mdns_browser_finalize;
 
+	g_type_class_add_private (klass, sizeof (DmapMdnsBrowserPrivate));
+
 	dmap_mdns_browser_signals[SERVICE_ADDED] =
 		g_signal_new ("service-added",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (DMAPMdnsBrowserClass,
+			      G_STRUCT_OFFSET (DmapMdnsBrowserClass,
 					       service_added), NULL, NULL,
-			      NULL, G_TYPE_NONE,
-			      1, G_TYPE_POINTER);
+			      g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE,
+			      1, DMAP_TYPE_MDNS_SERVICE);
 	dmap_mdns_browser_signals[SERVICE_REMOVED] =
 		g_signal_new ("service-removed",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (DMAPMdnsBrowserClass,
+			      G_STRUCT_OFFSET (DmapMdnsBrowserClass,
 					       service_removed), NULL, NULL,
-			      NULL, G_TYPE_NONE, 1,
+			      g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
 }
 
 static void
-dmap_mdns_browser_init (DMAPMdnsBrowser * browser)
+dmap_mdns_browser_init (DmapMdnsBrowser * browser)
 {
-	browser->priv = dmap_mdns_browser_get_instance_private(browser);
+	browser->priv = DMAP_MDNS_BROWSER_GET_PRIVATE (browser);
 	avahi_client_init (browser);
 }
 
-static void
-_wrapper(void *p)
-{
-	avahi_service_resolver_free(p);
-}
-
 static void
 dmap_mdns_browser_dispose (GObject * object)
 {
-	DMAPMdnsBrowser *browser = DMAP_MDNS_BROWSER (object);
+	DmapMdnsBrowser *browser = DMAP_MDNS_BROWSER (object);
 	GSList *walk;
-	DMAPMdnsBrowserService *service;
+	DmapMdnsService *service;
 
 	for (walk = browser->priv->services; walk; walk = walk->next) {
-		service = (DMAPMdnsBrowserService *) walk->data;
-		free_service (service);
+		service = (DmapMdnsService *) walk->data;
+		g_object_unref (service);
 	}
 	g_slist_free (browser->priv->services);
 
 	if (browser->priv->resolvers) {
-		g_slist_free_full (browser->priv->resolvers, _wrapper);
+		g_slist_foreach (browser->priv->resolvers,
+				 (GFunc) avahi_service_resolver_free, NULL);
+		g_slist_free (browser->priv->resolvers);
 	}
 
 	if (browser->priv->service_browser) {
@@ -188,13 +197,13 @@ dmap_mdns_browser_finalize (GObject * object)
 	G_OBJECT_CLASS (dmap_mdns_browser_parent_class)->finalize (object);
 }
 
-DMAPMdnsBrowser *
-dmap_mdns_browser_new (DMAPMdnsBrowserServiceType type)
+DmapMdnsBrowser *
+dmap_mdns_browser_new (DmapMdnsServiceType type)
 {
-	DMAPMdnsBrowser *browser_object;
+	DmapMdnsBrowser *browser_object;
 
-	g_return_val_if_fail (type >= DMAP_MDNS_BROWSER_SERVICE_TYPE_INVALID
-			      && type <= DMAP_MDNS_BROWSER_SERVICE_TYPE_LAST,
+	g_return_val_if_fail (type >= DMAP_MDNS_SERVICE_TYPE_INVALID
+			      && type <= DMAP_MDNS_SERVICE_TYPE_LAST,
 			      NULL);
 
 	browser_object =
@@ -206,7 +215,7 @@ dmap_mdns_browser_new (DMAPMdnsBrowserServiceType type)
 }
 
 gboolean
-dmap_mdns_browser_start (DMAPMdnsBrowser * browser, GError ** error)
+dmap_mdns_browser_start (DmapMdnsBrowser * browser, GError ** error)
 {
 	if (browser->priv->client == NULL) {
 		g_set_error (error,
@@ -227,7 +236,9 @@ dmap_mdns_browser_start (DMAPMdnsBrowser * browser, GError ** error)
 					   service_type_name[browser->
 							     priv->service_type],
 					   NULL,
+#ifdef HAVE_AVAHI_0_6
 					   0,
+#endif
 					   (AvahiServiceBrowserCallback)
 					   browse_cb, browser);
 	if (browser->priv->service_browser == NULL) {
@@ -244,7 +255,7 @@ dmap_mdns_browser_start (DMAPMdnsBrowser * browser, GError ** error)
 }
 
 gboolean
-dmap_mdns_browser_stop (DMAPMdnsBrowser * browser, GError ** error)
+dmap_mdns_browser_stop (DmapMdnsBrowser * browser, GError ** error)
 {
 	if (browser->priv->client == NULL) {
 		g_set_error (error,
@@ -266,43 +277,43 @@ dmap_mdns_browser_stop (DMAPMdnsBrowser * browser, GError ** error)
 	return TRUE;
 }
 
-const GSList *
-dmap_mdns_browser_get_services (DMAPMdnsBrowser * browser)
+G_CONST_RETURN GSList *
+dmap_mdns_browser_get_services (DmapMdnsBrowser * browser)
 {
 	g_return_val_if_fail (browser != NULL, NULL);
 	return browser->priv->services;
 }
 
-DMAPMdnsBrowserServiceType
-dmap_mdns_browser_get_service_type (DMAPMdnsBrowser * browser)
+DmapMdnsServiceType
+dmap_mdns_browser_get_service_type (DmapMdnsBrowser * browser)
 {
 	g_return_val_if_fail (browser != NULL,
-			      DMAP_MDNS_BROWSER_SERVICE_TYPE_INVALID);
+			      DMAP_MDNS_SERVICE_TYPE_INVALID);
 	return browser->priv->service_type;
 }
 
 static void
 client_cb (AvahiClient * client,
-	   AvahiClientState state,
-           G_GNUC_UNUSED DMAPMdnsBrowser * browser)
+	   AvahiClientState state, DmapMdnsBrowser * browser)
 {
 	/* Called whenever the client or server state changes */
 
 	switch (state) {
+#ifdef HAVE_AVAHI_0_6
 	case AVAHI_CLIENT_FAILURE:
 		g_warning ("Client failure: %s\n",
 			   avahi_strerror (avahi_client_errno (client)));
 		break;
+#endif
 	default:
 		break;
 	}
 }
 
 static void
-avahi_client_init (DMAPMdnsBrowser * browser)
+avahi_client_init (DmapMdnsBrowser * browser)
 {
 	gint error = 0;
-	AvahiClientFlags flags = 0;
 
 	avahi_set_allocator (avahi_glib_allocator ());
 
@@ -311,34 +322,47 @@ avahi_client_init (DMAPMdnsBrowser * browser)
 	if (!browser->priv->poll) {
 		g_debug ("Unable to create AvahiGlibPoll object for mDNS");
 	}
-
+#ifdef HAVE_AVAHI_0_5
 	browser->priv->client =
-		avahi_client_new (avahi_glib_poll_get
-				  (browser->priv->poll), flags,
-				  (AvahiClientCallback) client_cb,
-				  browser, &error);
+		avahi_client_new (avahi_glib_poll_get (browser->priv->poll),
+				  (AvahiClientCallback) client_cb, browser,
+				  &error);
+#endif
+#ifdef HAVE_AVAHI_0_6
+	{
+		AvahiClientFlags flags = 0;
+
+		browser->priv->client =
+			avahi_client_new (avahi_glib_poll_get
+					  (browser->priv->poll), flags,
+					  (AvahiClientCallback) client_cb,
+					  browser, &error);
+	}
+#endif
 }
 
 static void
 resolve_cb (AvahiServiceResolver * service_resolver,
-	    G_GNUC_UNUSED AvahiIfIndex interface,
-	    G_GNUC_UNUSED AvahiProtocol protocol,
+	    AvahiIfIndex interface,
+	    AvahiProtocol protocol,
 	    AvahiResolverEvent event,
 	    const gchar * service_name,
 	    const gchar * type,
 	    const gchar * domain,
-	    G_GNUC_UNUSED const gchar * host_name,
+	    const gchar * host_name,
 	    const AvahiAddress * address,
 	    uint16_t port, AvahiStringList * text,
-	    G_GNUC_UNUSED AvahiLookupResultFlags flags,
-	    DMAPMdnsBrowser * browser)
+#ifdef HAVE_AVAHI_0_6
+	    AvahiLookupResultFlags flags,
+#endif
+	    DmapMdnsBrowser * browser)
 {
 	gchar *name = NULL;
 	gchar *pair = NULL;	/* FIXME: extract DACP-specific items into sub-class. Ensure in Howl and dns-sd code too. */
-	DMAPMdnsBrowserTransportProtocol transport_protocol = DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL_TCP; // FIXME: subclass
+	DmapMdnsServiceTransportProtocol transport_protocol = DMAP_MDNS_SERVICE_TRANSPORT_PROTOCOL_TCP; // FIXME: subclass
 	gchar host[AVAHI_ADDRESS_STR_MAX];
 	gboolean pp = FALSE;
-	DMAPMdnsBrowserService *service;
+	DmapMdnsService *service;
 
 	switch (event) {
 	case AVAHI_RESOLVER_FAILURE:
@@ -391,8 +415,8 @@ resolve_cb (AvahiServiceResolver * service_resolver,
 				} else if (strcmp (key, "tp") == 0) {
 					/* RAOP transport protocol */
 					transport_protocol = strstr (value, "UDP")
-					                   ? DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL_UDP
-							   : DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL_TCP;
+					                   ? DMAP_MDNS_SERVICE_TRANSPORT_PROTOCOL_UDP
+							   : DMAP_MDNS_SERVICE_TRANSPORT_PROTOCOL_TCP;
 				}
 
 				g_free (key);
@@ -400,20 +424,21 @@ resolve_cb (AvahiServiceResolver * service_resolver,
 			}
 		}
 
-		if (name == NULL) {
-			name = g_strdup (service_name);
-		}
-
 		avahi_address_snprint (host, AVAHI_ADDRESS_STR_MAX, address);
 
-		service = g_new0 (DMAPMdnsBrowserService, 1);
-		service->service_name = g_strdup (service_name);
-		service->name = name;
-		service->host = g_strdup (host);
-		service->port = port;
-		service->pair = pair; // FIXME: subclass
-		service->transport_protocol = transport_protocol; // FIXME: subclass
-		service->password_protected = pp;
+		service = g_object_new (DMAP_TYPE_MDNS_SERVICE,
+		                       "service-name", service_name,
+		                       "name", name,
+		                       "host", host,
+		                       "port", port,
+		                       "pair", pair, // FIXME: subclass.
+		                       "transport-protocol", transport_protocol, // FIXME: subclass.
+		                       "password-protected", pp,
+		                        NULL);
+
+		g_free(name);
+		g_free(pair);
+
 		browser->priv->services =
 			g_slist_append (browser->priv->services, service);
 		g_signal_emit (browser,
@@ -431,7 +456,7 @@ resolve_cb (AvahiServiceResolver * service_resolver,
 }
 
 static gboolean
-dmap_mdns_browser_resolve (DMAPMdnsBrowser * browser,
+dmap_mdns_browser_resolve (DmapMdnsBrowser * browser,
 			   const gchar * name, const gchar * domain)
 {
 	AvahiServiceResolver *service_resolver;
@@ -445,7 +470,9 @@ dmap_mdns_browser_resolve (DMAPMdnsBrowser * browser,
 							priv->service_type],
 						       domain,
 						       AVAHI_PROTO_UNSPEC,
+#ifdef HAVE_AVAHI_0_6
 						       0,
+#endif
 						       (AvahiServiceResolverCallback) resolve_cb, browser);
 	if (service_resolver == NULL) {
 		g_debug ("Error starting mDNS resolving using AvahiServiceResolver");
@@ -459,14 +486,14 @@ dmap_mdns_browser_resolve (DMAPMdnsBrowser * browser,
 }
 
 static void
-browser_add_service (DMAPMdnsBrowser * browser,
+browser_add_service (DmapMdnsBrowser * browser,
 		     const gchar * service_name, const gchar * domain)
 {
 	dmap_mdns_browser_resolve (browser, service_name, domain);
 }
 
 static void
-browser_remove_service (DMAPMdnsBrowser * browser, const gchar * service_name)
+browser_remove_service (DmapMdnsBrowser * browser, const gchar * service_name)
 {
 	g_signal_emit (browser,
 		       dmap_mdns_browser_signals[SERVICE_REMOVED],
@@ -474,20 +501,26 @@ browser_remove_service (DMAPMdnsBrowser * browser, const gchar * service_name)
 }
 
 static void
-browse_cb (G_GNUC_UNUSED AvahiServiceBrowser * service_browser,
-	   G_GNUC_UNUSED AvahiIfIndex interface,
-	   G_GNUC_UNUSED AvahiProtocol protocol,
+browse_cb (AvahiServiceBrowser * service_browser,
+	   AvahiIfIndex interface,
+	   AvahiProtocol protocol,
 	   AvahiBrowserEvent event,
-	   const gchar * name,
-           G_GNUC_UNUSED const gchar * type,
-           const gchar * domain,
+	   const gchar * name, const gchar * type, const gchar * domain,
+#ifdef HAVE_AVAHI_0_6
 	   AvahiLookupResultFlags flags,
-	   DMAPMdnsBrowser * browser)
+#endif
+	   DmapMdnsBrowser * browser)
 {
 	gboolean local;
 
+#ifdef HAVE_AVAHI_0_5
+	local = avahi_client_is_service_local (browser->priv->client,
+					       interface, protocol, name,
+					       type, domain);
+#endif
+#ifdef HAVE_AVAHI_0_6
 	local = ((flags & AVAHI_LOOKUP_RESULT_LOCAL) != 0);
-
+#endif
 	if (local && getenv ("LIBDMAPSHARING_ENABLE_LOCAL") == NULL) {
 		g_debug ("Ignoring local service %s", name);
 		return;
@@ -499,13 +532,3 @@ browse_cb (G_GNUC_UNUSED AvahiServiceBrowser * service_browser,
 		browser_remove_service (browser, name);
 	}
 }
-
-static void
-free_service (DMAPMdnsBrowserService * service)
-{
-	g_free (service->service_name);
-	g_free (service->name);
-	g_free (service->host);
-	g_free (service->pair);
-	g_free (service);
-}
