@@ -30,9 +30,9 @@
 
 #include "dmap-mdns-browser.h"
 
-struct _DMAPMdnsBrowserPrivate
+struct _DmapMdnsBrowserPrivate
 {
-	DMAPMdnsBrowserServiceType service_type;
+	DmapMdnsServiceType service_type;
 	DNSServiceRef sd_browse_ref;
 	GSList *services;
 	GSList *backlog;
@@ -42,10 +42,10 @@ typedef struct _ServiceContext
 {
 	DNSServiceRef service_discovery_ref;
 	DNSServiceRef host_lookup_ref;
-	DMAPMdnsBrowser *browser;
+	DmapMdnsBrowser *browser;
 	DNSServiceFlags flags;
 	uint32_t interface_index;
-	DMAPMdnsBrowserService service;
+	DmapMdnsService *service;
 	gchar *domain;
 } ServiceContext;
 
@@ -56,28 +56,18 @@ enum
 	LAST_SIGNAL
 };
 
+#define DMAP_MDNS_BROWSER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_MDNS_BROWSER, DmapMdnsBrowserPrivate))
+
 static guint dmap_mdns_browser_signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE_WITH_PRIVATE (DMAPMdnsBrowser, dmap_mdns_browser, G_TYPE_OBJECT);
+G_DEFINE_TYPE (DmapMdnsBrowser, dmap_mdns_browser, G_TYPE_OBJECT);
 
 static void
-dmap_mdns_browser_init (DMAPMdnsBrowser * browser)
+dmap_mdns_browser_init (DmapMdnsBrowser * browser)
 {
 	g_assert (NULL != browser);
 
-	browser->priv = dmap_mdns_browser_get_instance_private(browser);
-}
-
-static void
-free_service (DMAPMdnsBrowserService * service)
-{
-	g_assert (NULL != service);
-
-	g_free (service->service_name);
-	g_free (service->name);
-	g_free (service->host);
-	g_free (service->pair);
-	g_free (service);
+	browser->priv = DMAP_MDNS_BROWSER_GET_PRIVATE (browser);
 }
 
 static void
@@ -86,8 +76,7 @@ service_context_free (ServiceContext *ctx)
 	g_assert (NULL != ctx);
 	g_assert (NULL != ctx->browser);
 
-	free_service (&ctx->service);
-
+	g_object_unref (&ctx->service);
 	g_object_unref (ctx->browser);
 
 	g_free (ctx->domain);
@@ -99,20 +88,40 @@ signal_service_added (ServiceContext *context)
 {
 	g_assert (NULL != context);
 
-	DMAPMdnsBrowserService *service;
+	gchar                           *service_name       = NULL;
+	gchar                           *name               = NULL;
+	gchar                           *host               = NULL;
+	uint16_t                         port               = 0;
+	gchar                           *pair               = NULL;
+	DmapMdnsServiceTransportProtocol transport_protocol = DMAP_MDNS_SERVICE_TRANSPORT_PROTOCOL_TCP;
+	gboolean                         password_protected = FALSE;
 
-	service = g_new0 (DMAPMdnsBrowserService, 1);
+	DmapMdnsService *service;
+
+	g_object_get(context->service,
+	            "service-name", &service_name,
+	            "name", &name,
+	            "host", &host,
+	            "port", &port,
+	            "pair", &pair,
+	            "transport-protocol", transport_protocol,
+	            "password-protected", password_protected,
+	             NULL);
 
 	// FIXME: The name and service_name variables need to be renamed.
 	// Wait until working on DACP because I think this is when
 	// they are different. See Avahi code.
-	service->service_name = g_strdup (context->service.service_name);
-	service->name = g_strdup (context->service.name);
-	service->host = g_strdup (context->service.host);
-	service->port = context->service.port;
-	service->pair = g_strdup (context->service.pair);
-	service->password_protected = context->service.password_protected;
-	service->transport_protocol = DMAP_MDNS_BROWSER_TRANSPORT_PROTOCOL_TCP;
+	service = g_object_new(DMAP_TYPE_MDNS_SERVICE,
+	                      "service-name", service_name,
+	                      "name", name,
+	                      "host", host,
+	                      "port", port,
+	                      "pair", pair,
+	                      "transport-protocol", transport_protocol,
+	                      "password-protected", password_protected,
+	                       NULL);
+
+	service = g_new0 (DmapMdnsService, 1);
 
 	// add to the services list
 	context->browser->priv->services =
@@ -160,13 +169,13 @@ done:
 }
 
 static void
-dns_service_browse_reply (G_GNUC_UNUSED DNSServiceRef sd_ref,
-                          DNSServiceFlags flags,
-                          uint32_t interface_index,
-                          DNSServiceErrorType error_code,
-                          const char *service_name,
-                          G_GNUC_UNUSED const char *regtype,
-                          const char *domain, void *udata)
+dns_service_browse_reply (DNSServiceRef sd_ref,
+			  DNSServiceFlags flags,
+			  uint32_t interface_index,
+			  DNSServiceErrorType error_code,
+			  const char *service_name,
+			  const char *regtype,
+			  const char *domain, void *udata)
 {
 	if (error_code != kDNSServiceErr_NoError) {
 		g_warning ("dnsServiceBrowserReply ():  fail");
@@ -177,14 +186,15 @@ dns_service_browse_reply (G_GNUC_UNUSED DNSServiceRef sd_ref,
 		goto done;
 	}
 
-	DMAPMdnsBrowser *browser = (DMAPMdnsBrowser *) udata;
+	DmapMdnsBrowser *browser = (DmapMdnsBrowser *) udata;
 
 	ServiceContext *context = g_new0 (ServiceContext, 1);
 	context->browser = g_object_ref (browser);
 	context->flags = flags;
 	context->interface_index = interface_index;
-	context->service.service_name = g_strdup (service_name);
 	context->domain = g_strdup (domain);
+	context->service = g_object_new(DMAP_TYPE_MDNS_SERVICE, NULL);
+	g_object_set(context->service, "service-name", service_name, NULL);
 
 	browser->priv->backlog = g_slist_prepend (browser->priv->backlog, context);
 
@@ -192,15 +202,14 @@ done:
 	return;
 }
 
-/*
 static void
-dns_host_resolve_reply (G_GNUC_UNUSED DNSServiceRef sd_ref,
-                        G_GNUC_UNUSED DNSServiceFlags flags,
-                        G_GNUC_UNUSED uint32_t interface_index,
+dns_host_resolve_reply (DNSServiceRef sd_ref,
+                        DNSServiceFlags flags,
+                        uint32_t interface_index,
                         DNSServiceErrorType error_code,
-                        G_GNUC_UNUSED const char *hostname,
+                        const char *hostname,
                         const struct sockaddr *address,
-                        G_GNUC_UNUSED uint32_t ttl,
+                        uint32_t ttl,
                         void *udata)
 {
 	ServiceContext *ctx = (ServiceContext *) udata;
@@ -212,28 +221,28 @@ dns_host_resolve_reply (G_GNUC_UNUSED DNSServiceRef sd_ref,
 
 	switch(address->sa_family) {
 	case AF_INET: {
+		gchar host[INET_ADDRSTRLEN];
 		struct sockaddr_in *addr_in = (struct sockaddr_in *) address;
-		ctx->service.host = malloc(INET_ADDRSTRLEN);
-		inet_ntop(AF_INET, &(addr_in->sin_addr), ctx->service.host, INET_ADDRSTRLEN);
+		inet_ntop(AF_INET, &(addr_in->sin_addr), host, INET_ADDRSTRLEN);
+		g_object_set(&ctx->service, "host", host, NULL);
 		break;
 	}
 	case AF_INET6: {
+		gchar host[INET6_ADDRSTRLEN];
 		struct sockaddr_in6 *addr_in6 = (struct sockaddr_in6 *) address;
-		ctx->service.host = malloc(INET6_ADDRSTRLEN);
-		inet_ntop(AF_INET6, &(addr_in6->sin6_addr), ctx->service.host, INET6_ADDRSTRLEN);
+		inet_ntop(AF_INET6, &(addr_in6->sin6_addr), host, INET6_ADDRSTRLEN);
+		g_object_set(&ctx->service, "host", host, NULL);
 		break;
 	}
 	default:
-		ctx->service.host = NULL;
+		g_object_set(&ctx->service, "host", NULL, NULL);
 		break;
 	}
 }
-*/
 
 static gboolean
-lookup_result_available_cb (G_GNUC_UNUSED GIOChannel * gio,
-                            GIOCondition condition,
-                            ServiceContext *context)
+lookup_result_available_cb (GIOChannel * gio, GIOCondition condition,
+                             ServiceContext *context)
 {
 	gboolean fnval = FALSE;
 
@@ -280,15 +289,15 @@ add_host_lookup_to_event_loop (ServiceContext *context)
 }
 
 static void
-dns_service_resolve_reply (G_GNUC_UNUSED DNSServiceRef sd_ref,
-                           DNSServiceFlags flags,
-                           uint32_t interface_index,
-                           DNSServiceErrorType error_code,
-                           const char *name,
-                           G_GNUC_UNUSED const char *host,
-                           uint16_t port,
-                           G_GNUC_UNUSED uint16_t txt_len,
-                           G_GNUC_UNUSED const char *txt_record,
+dns_service_resolve_reply (DNSServiceRef sd_ref,
+			   DNSServiceFlags flags,
+			   uint32_t interface_index,
+			   DNSServiceErrorType error_code,
+			   const char *name,
+			   const char *host,
+			   uint16_t port,
+			   uint16_t txt_len,
+			   const char *txt_record,
                            void *udata)
 {
 	DNSServiceRef ref;
@@ -301,10 +310,12 @@ dns_service_resolve_reply (G_GNUC_UNUSED DNSServiceRef sd_ref,
 
 	ctx->flags = flags;
 	ctx->interface_index = interface_index;
-	ctx->service.port = htons (port);
-	ctx->service.name = extract_name (name);
-	ctx->service.pair = NULL;
-	ctx->service.password_protected = FALSE;
+	g_object_set(ctx->service,
+	            "port", htons(port),
+	            "name", extract_name (name),
+	            "pair", NULL,
+	            "password-protected", FALSE,
+	             NULL);
 
 	g_error("FIXME: Not implemented");
 /*
@@ -327,8 +338,7 @@ dns_service_resolve_reply (G_GNUC_UNUSED DNSServiceRef sd_ref,
 }
 
 static gboolean
-service_result_available_cb (G_GNUC_UNUSED GIOChannel * gio,
-                             GIOCondition condition,
+service_result_available_cb (GIOChannel * gio, GIOCondition condition,
                              ServiceContext *context)
 {
 	gboolean fnval = FALSE;
@@ -370,9 +380,8 @@ add_service_discovery_to_event_loop (ServiceContext *context)
 }
 
 static gboolean
-browse_result_available_cb (G_GNUC_UNUSED GIOChannel * gio,
-                            GIOCondition condition,
-                            DMAPMdnsBrowser * browser)
+browse_result_available_cb (GIOChannel * gio,
+			    GIOCondition condition, DmapMdnsBrowser * browser)
 {
 	gboolean fnval = FALSE;
 
@@ -388,13 +397,16 @@ browse_result_available_cb (G_GNUC_UNUSED GIOChannel * gio,
 	}
 
 	while (browser->priv->backlog) {
+		gchar *service_name;
 		DNSServiceRef ref;
 		ServiceContext *ctx = (ServiceContext *) browser->priv->backlog->data;
 
+		g_object_get(ctx->service, "service-name", &service_name, NULL);
+
 		err = DNSServiceResolve (&ref,
 		                         ctx->flags,
 		                         ctx->interface_index,
-		                         ctx->service.service_name,
+		                         service_name,
 		                         service_type_name[browser->priv->service_type],
 		                         ctx->domain,
 		                         (DNSServiceResolveReply)
@@ -421,7 +433,7 @@ done:
 }
 
 static gboolean
-add_browse_to_event_loop (DMAPMdnsBrowser *browser)
+add_browse_to_event_loop (DmapMdnsBrowser *browser)
 {
 	gboolean fnval = FALSE;
 
@@ -447,13 +459,13 @@ done:
 static void
 dmap_mdns_browser_dispose (GObject * object)
 {
-	DMAPMdnsBrowser *browser = DMAP_MDNS_BROWSER (object);
+	DmapMdnsBrowser *browser = DMAP_MDNS_BROWSER (object);
 	GSList *walk;
-	DMAPMdnsBrowserService *service;
+	DmapMdnsService *service;
 
 	for (walk = browser->priv->services; NULL != walk; walk = walk->next) {
-		service = (DMAPMdnsBrowserService *) walk->data;
-		free_service (service);
+		service = (DmapMdnsService *) walk->data;
+		g_object_unref (service);
 	}
 
 	g_slist_free (browser->priv->services);
@@ -469,7 +481,7 @@ dmap_mdns_browser_finalize (GObject * object)
 }
 
 static void
-dmap_mdns_browser_class_init (DMAPMdnsBrowserClass * klass)
+dmap_mdns_browser_class_init (DmapMdnsBrowserClass * klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
@@ -478,33 +490,35 @@ dmap_mdns_browser_class_init (DMAPMdnsBrowserClass * klass)
 	object_class->dispose = dmap_mdns_browser_dispose;
 	object_class->finalize = dmap_mdns_browser_finalize;
 
+	g_type_class_add_private (klass, sizeof (DmapMdnsBrowserPrivate));
+
 	// Signal makeup
 	dmap_mdns_browser_signals[SERVICE_ADDED] =
 		g_signal_new ("service-added",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (DMAPMdnsBrowserClass,
+			      G_STRUCT_OFFSET (DmapMdnsBrowserClass,
 					       service_added), NULL, NULL,
-			      NULL, G_TYPE_NONE,
+			      g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE,
 			      1, G_TYPE_POINTER);
 
 	dmap_mdns_browser_signals[SERVICE_REMOVED] =
 		g_signal_new ("service-removed",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (DMAPMdnsBrowserClass,
+			      G_STRUCT_OFFSET (DmapMdnsBrowserClass,
 					       service_removed), NULL, NULL,
-			      NULL, G_TYPE_NONE, 1,
+			      g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
 }
 
-DMAPMdnsBrowser *
-dmap_mdns_browser_new (DMAPMdnsBrowserServiceType type)
+DmapMdnsBrowser *
+dmap_mdns_browser_new (DmapMdnsServiceType type)
 {
-	DMAPMdnsBrowser *browser_object = 0;
+	DmapMdnsBrowser *browser_object = 0;
 
-	g_return_val_if_fail (type >= DMAP_MDNS_BROWSER_SERVICE_TYPE_INVALID
-			      && type <= DMAP_MDNS_BROWSER_SERVICE_TYPE_LAST,
+	g_return_val_if_fail (type >= DMAP_MDNS_SERVICE_TYPE_INVALID
+			      && type <= DMAP_MDNS_SERVICE_TYPE_LAST,
 			      NULL);
 
 	browser_object = DMAP_MDNS_BROWSER (g_object_new
@@ -517,7 +531,7 @@ dmap_mdns_browser_new (DMAPMdnsBrowserServiceType type)
 }
 
 gboolean
-dmap_mdns_browser_start (DMAPMdnsBrowser * browser, GError ** error)
+dmap_mdns_browser_start (DmapMdnsBrowser * browser, GError ** error)
 {
 	gboolean fnval = FALSE;
 
@@ -546,8 +560,7 @@ dmap_mdns_browser_start (DMAPMdnsBrowser * browser, GError ** error)
 }
 
 gboolean
-dmap_mdns_browser_stop (DMAPMdnsBrowser * browser,
-                        G_GNUC_UNUSED GError ** error)
+dmap_mdns_browser_stop (DmapMdnsBrowser * browser, GError ** error)
 {
 	if (NULL != browser->priv->sd_browse_ref) {
 		DNSServiceRefDeallocate (browser->priv->sd_browse_ref);
@@ -570,19 +583,19 @@ dmap_mdns_browser_error_quark (void)
 	return quark;
 }
 
-const GSList *
-dmap_mdns_browser_get_services (DMAPMdnsBrowser * browser)
+G_CONST_RETURN GSList *
+dmap_mdns_browser_get_services (DmapMdnsBrowser * browser)
 {
 	g_return_val_if_fail (browser != NULL, NULL);
 
 	return browser->priv->services;
 }
 
-DMAPMdnsBrowserServiceType
-dmap_mdns_browser_get_service_type (DMAPMdnsBrowser * browser)
+DmapMdnsServiceType
+dmap_mdns_browser_get_service_type (DmapMdnsBrowser * browser)
 {
 	g_return_val_if_fail (browser != NULL,
-			      DMAP_MDNS_BROWSER_SERVICE_TYPE_INVALID);
+			      DMAP_MDNS_SERVICE_TYPE_INVALID);
 
 	return browser->priv->service_type;
 }
