@@ -38,13 +38,13 @@
 #include "dmap-mdns-avahi.h"
 #include "dmap-mdns-publisher.h"
 
-static void dmap_mdns_publisher_class_init (DMAPMdnsPublisherClass * klass);
-static void dmap_mdns_publisher_init (DMAPMdnsPublisher * publisher);
+static void dmap_mdns_publisher_class_init (DmapMdnsPublisherClass * klass);
+static void dmap_mdns_publisher_init (DmapMdnsPublisher * publisher);
 static void dmap_mdns_publisher_finalize (GObject * object);
 
-#define DMAP_MDNS_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_MDNS_PUBLISHER, DMAPMdnsPublisherPrivate))
+#define DMAP_MDNS_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_MDNS_PUBLISHER, DmapMdnsPublisherPrivate))
 
-struct DMAPMdnsPublisherService
+struct DmapMdnsPublisherService
 {
 	char *name;
 	guint port;
@@ -53,7 +53,7 @@ struct DMAPMdnsPublisherService
 	gchar **txt_records;
 };
 
-struct DMAPMdnsPublisherPrivate
+struct DmapMdnsPublisherPrivate
 {
 	AvahiClient *client;
 	AvahiEntryGroup *entry_group;
@@ -67,14 +67,9 @@ enum
 	LAST_SIGNAL
 };
 
-enum
-{
-	PROP_0
-};
-
 static guint signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE (DMAPMdnsPublisher, dmap_mdns_publisher, G_TYPE_OBJECT);
+G_DEFINE_TYPE (DmapMdnsPublisher, dmap_mdns_publisher, G_TYPE_OBJECT);
 
 static gpointer publisher_object = NULL;
 
@@ -91,14 +86,14 @@ dmap_mdns_publisher_error_quark (void)
 }
 
 static void
-emit_published (char *name, DMAPMdnsPublisher * publisher)
+emit_published (char *name, DmapMdnsPublisher * publisher)
 {
 	g_signal_emit (publisher, signals[PUBLISHED], 0, name);
 }
 
 static void
 entry_group_cb (AvahiEntryGroup * group,
-		AvahiEntryGroupState state, DMAPMdnsPublisher * publisher)
+		AvahiEntryGroupState state, DmapMdnsPublisher * publisher)
 {
 	if (state == AVAHI_ENTRY_GROUP_ESTABLISHED) {
 		g_slist_foreach (publisher->priv->service,
@@ -115,8 +110,8 @@ entry_group_cb (AvahiEntryGroup * group,
 }
 
 static gboolean
-create_service (struct DMAPMdnsPublisherService *service,
-		DMAPMdnsPublisher * publisher, GError ** error)
+create_service (struct DmapMdnsPublisherService *service,
+		DmapMdnsPublisher * publisher, GError ** error)
 {
 	int ret;
 	const char *password_record;
@@ -145,7 +140,8 @@ create_service (struct DMAPMdnsPublisherService *service,
 	ret = avahi_entry_group_add_service_strlst (publisher->
 						    priv->entry_group,
 						    AVAHI_IF_UNSPEC,
-						    AVAHI_PROTO_UNSPEC, 0,
+						    AVAHI_PROTO_UNSPEC,
+	                                            0,
 						    service->name,
 						    service->type_of_service,
 						    NULL, NULL, service->port,
@@ -167,9 +163,12 @@ create_service (struct DMAPMdnsPublisherService *service,
 }
 
 static gboolean
-create_services (DMAPMdnsPublisher * publisher, GError ** error)
+create_services (DmapMdnsPublisher * publisher, GError ** error)
 {
-	GSList *ptr;
+	static int suffix = 0;
+	gchar *name;
+	GSList *ptr1, *ptr2;
+	struct DmapMdnsPublisherService *service1, *service2;
 	int ret;
 
 	if (publisher->priv->entry_group == NULL) {
@@ -195,8 +194,25 @@ create_services (DMAPMdnsPublisher * publisher, GError ** error)
 		avahi_entry_group_reset (publisher->priv->entry_group);
 	}
 
-	for (ptr = publisher->priv->service; ptr; ptr = g_slist_next (ptr)) {
-		if (!create_service (ptr->data, publisher, error)) {
+	for (ptr1 = publisher->priv->service; ptr1; ptr1 = g_slist_next (ptr1)) {
+		service1 = ptr1->data;
+		name = service1->name;
+		for (ptr2 = publisher->priv->service; ptr2; ptr2 = g_slist_next (ptr2)) {
+			if (ptr1 == ptr2) {
+				continue;
+			}
+			service2 = ptr2->data;
+			if (!strcmp(service1->name, service2->name)
+			 && !strcmp(service1->type_of_service, service2->type_of_service)) {
+				name = g_strdup_printf("%s-%d", service1->name, suffix++);
+			}
+		}
+		if (strcmp(name, service1->name)) {
+			g_free(service1->name);
+			service1->name = name;
+			g_signal_emit (publisher, signals[NAME_COLLISION], 0, name);
+		}
+		if (!create_service (service1, publisher, error)) {
 			return FALSE;
 		}
 	}
@@ -217,19 +233,19 @@ create_services (DMAPMdnsPublisher * publisher, GError ** error)
 }
 
 static gboolean
-refresh_services (DMAPMdnsPublisher * publisher, GError ** error)
+refresh_services (DmapMdnsPublisher * publisher, GError ** error)
 {
 	return create_services (publisher, error);
 }
 
-static struct DMAPMdnsPublisherService *
+static struct DmapMdnsPublisherService *
 find_service_by_port (GSList * list, guint port)
 {
 	GSList *ptr;
 
 	for (ptr = list; ptr; ptr = g_slist_next (ptr)) {
 		if (port ==
-		    ((struct DMAPMdnsPublisherService *) ptr->data)->port)
+		    ((struct DmapMdnsPublisherService *) ptr->data)->port)
 			break;
 	}
 
@@ -237,11 +253,11 @@ find_service_by_port (GSList * list, guint port)
 }
 
 gboolean
-dmap_mdns_publisher_rename_at_port (DMAPMdnsPublisher * publisher,
+dmap_mdns_publisher_rename_at_port (DmapMdnsPublisher * publisher,
 				    guint port,
 				    const char *name, GError ** error)
 {
-	struct DMAPMdnsPublisherService *ptr;
+	struct DmapMdnsPublisherService *ptr;
 
 	g_return_val_if_fail (publisher != NULL, FALSE);
 
@@ -266,14 +282,14 @@ dmap_mdns_publisher_rename_at_port (DMAPMdnsPublisher * publisher,
 }
 
 gboolean
-dmap_mdns_publisher_publish (DMAPMdnsPublisher * publisher,
+dmap_mdns_publisher_publish (DmapMdnsPublisher * publisher,
 			     const char *name,
 			     guint port,
 			     const char *type_of_service,
 			     gboolean password_required,
 			     gchar ** txt_records, GError ** error)
 {
-	struct DMAPMdnsPublisherService *service;
+	struct DmapMdnsPublisherService *service;
 
 	if (publisher->priv->client == NULL) {
 		g_set_error (error,
@@ -284,7 +300,7 @@ dmap_mdns_publisher_publish (DMAPMdnsPublisher * publisher,
 		return FALSE;
 	}
 
-	service = g_new0 (struct DMAPMdnsPublisherService, 1);
+	service = g_new0 (struct DmapMdnsPublisherService, 1);
 
 	service->name = g_strdup (name);
 	service->port = port;
@@ -299,7 +315,7 @@ dmap_mdns_publisher_publish (DMAPMdnsPublisher * publisher,
 }
 
 static void
-free_service (struct DMAPMdnsPublisherService *service, gpointer user_data)
+free_service (struct DmapMdnsPublisherService *service, gpointer user_data)
 {
 	g_free (service->name);
 	g_free (service->type_of_service);
@@ -308,10 +324,10 @@ free_service (struct DMAPMdnsPublisherService *service, gpointer user_data)
 }
 
 gboolean
-dmap_mdns_publisher_withdraw (DMAPMdnsPublisher * publisher,
+dmap_mdns_publisher_withdraw (DmapMdnsPublisher * publisher,
 			      guint port, GError ** error)
 {
-	struct DMAPMdnsPublisherService *ptr;
+	struct DmapMdnsPublisherService *ptr;
 
 	if (publisher->priv->client == NULL) {
 		g_set_error (error,
@@ -331,9 +347,9 @@ dmap_mdns_publisher_withdraw (DMAPMdnsPublisher * publisher,
 		return FALSE;
 	}
 
-	free_service (ptr, NULL);
 	publisher->priv->service =
 		g_slist_remove (publisher->priv->service, ptr);
+	free_service (ptr, NULL);
 
 	if (publisher->priv->service == NULL) {
 		avahi_entry_group_reset (publisher->priv->entry_group);
@@ -393,7 +409,7 @@ dmap_mdns_publisher_constructor (GType type,
 }
 
 static void
-dmap_mdns_publisher_class_init (DMAPMdnsPublisherClass * klass)
+dmap_mdns_publisher_class_init (DmapMdnsPublisherClass * klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
@@ -406,7 +422,7 @@ dmap_mdns_publisher_class_init (DMAPMdnsPublisherClass * klass)
 		g_signal_new ("published",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (DMAPMdnsPublisherClass,
+			      G_STRUCT_OFFSET (DmapMdnsPublisherClass,
 					       published), NULL, NULL,
 			      g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
@@ -414,16 +430,16 @@ dmap_mdns_publisher_class_init (DMAPMdnsPublisherClass * klass)
 		g_signal_new ("name-collision",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (DMAPMdnsPublisherClass,
+			      G_STRUCT_OFFSET (DmapMdnsPublisherClass,
 					       name_collision), NULL, NULL,
 			      g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
 
-	g_type_class_add_private (klass, sizeof (DMAPMdnsPublisherPrivate));
+	g_type_class_add_private (klass, sizeof (DmapMdnsPublisherPrivate));
 }
 
 static void
-dmap_mdns_publisher_init (DMAPMdnsPublisher * publisher)
+dmap_mdns_publisher_init (DmapMdnsPublisher * publisher)
 {
 	publisher->priv = DMAP_MDNS_PUBLISHER_GET_PRIVATE (publisher);
 
@@ -435,7 +451,7 @@ dmap_mdns_publisher_init (DMAPMdnsPublisher * publisher)
 static void
 dmap_mdns_publisher_finalize (GObject * object)
 {
-	DMAPMdnsPublisher *publisher;
+	DmapMdnsPublisher *publisher;
 
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (IS_DMAP_MDNS_PUBLISHER (object));
@@ -468,7 +484,7 @@ dmap_mdns_publisher_finalize (GObject * object)
 	G_OBJECT_CLASS (dmap_mdns_publisher_parent_class)->finalize (object);
 }
 
-DMAPMdnsPublisher *
+DmapMdnsPublisher *
 dmap_mdns_publisher_new (void)
 {
 	if (publisher_object) {
