@@ -22,10 +22,8 @@
 
 #include "dmap-private-utils.h"
 
-#define DMAP_SHARE_CHUNK_SIZE 16384
-
 void
-dmap_write_next_chunk (SoupMessage * message, ChunkData * cd)
+dmap_private_utils_write_next_chunk (SoupMessage * message, ChunkData * cd)
 {
 	gssize read_size;
 	GError *error = NULL;
@@ -38,7 +36,7 @@ dmap_write_next_chunk (SoupMessage * message, ChunkData * cd)
 	if (read_size > 0) {
 		soup_message_body_append (message->response_body,
 					  SOUP_MEMORY_TAKE, chunk, read_size);
-		g_debug ("Read/wrote %"G_GSSIZE_FORMAT" bytes.", read_size);
+		g_debug ("Read/wrote %ld bytes.", read_size);
 	} else {
 		if (error != NULL) {
 			g_warning ("Error reading from input stream: %s",
@@ -53,10 +51,14 @@ dmap_write_next_chunk (SoupMessage * message, ChunkData * cd)
 }
 
 void
-dmap_chunked_message_finished (G_GNUC_UNUSED SoupMessage * message,
-                               ChunkData * cd)
+dmap_private_utils_chunked_message_finished (SoupMessage * message, ChunkData * cd)
 {
 	g_debug ("Finished sending chunked file.");
 	g_input_stream_close (cd->stream, NULL, NULL);
+
+	if (cd->original_stream) {
+		g_input_stream_close (cd->original_stream, NULL, NULL);
+	}
+
 	g_free (cd);
 }
