@@ -1,5 +1,5 @@
 /*
- *  Database interface for a DMAPRecord Factory
+ *  Database interface for a DmapRecord Factory
  *
  *  Copyright (C) 2008 W. Michael Petullo <mike@flyn.org>
  *
@@ -20,42 +20,15 @@
 
 #include <libdmapsharing/dmap-record-factory.h>
 
-static gint dmap_record_factory_init_count = 0;
-
 static void
-dmap_record_factory_init (DMAPRecordFactoryIface * iface)
+dmap_record_factory_default_init (DmapRecordFactoryInterface * iface)
 {
-	dmap_record_factory_init_count++;
 }
 
-static void
-dmap_record_factory_finalize (DMAPRecordFactoryIface * iface)
-{
-	dmap_record_factory_init_count--;
-}
+G_DEFINE_INTERFACE(DmapRecordFactory, dmap_record_factory, G_TYPE_OBJECT)
 
-/* FIXME: No G_DEFINE_INTERFACE available in GObject headers: */
-GType
-dmap_record_factory_get_type (void)
-{
-	static GType object_type = 0;
-
-	if (!object_type) {
-		static const GTypeInfo object_info = {
-			sizeof (DMAPRecordFactoryIface),
-			(GBaseInitFunc) dmap_record_factory_init,
-			(GBaseFinalizeFunc) dmap_record_factory_finalize
-		};
-		object_type =
-			g_type_register_static (G_TYPE_INTERFACE,
-						"DMAPRecordFactory",
-						&object_info, 0);
-	}
-	return object_type;
-}
-
-DMAPRecord *
-dmap_record_factory_create (DMAPRecordFactory * factory, gpointer user_data)
+DmapRecord *
+dmap_record_factory_create (DmapRecordFactory * factory, gpointer user_data)
 {
 	return DMAP_RECORD_FACTORY_GET_INTERFACE (factory)->create (factory,
 								    user_data);
