@@ -18,8 +18,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __DMAP_RECORD_H
-#define __DMAP_RECORD_H
+#ifndef _DMAP_RECORD_H
+#define _DMAP_RECORD_H
 
 #include <glib-object.h>
 
@@ -27,19 +27,19 @@ G_BEGIN_DECLS
 /**
  * DMAP_TYPE_RECORD:
  *
- * The type for #DMAPRecord.
+ * The type for #DmapRecord.
  */
 #define DMAP_TYPE_RECORD	     (dmap_record_get_type ())
 /**
  * DMAP_RECORD:
  * @o: Object which is subject to casting.
  *
- * Casts a #DMAPRecord or derived pointer into a (DMAPRecord *) pointer.
+ * Casts a #DmapRecord or derived pointer into a (DmapRecord *) pointer.
  * Depending on the current debugging level, this function may invoke
  * certain runtime checks to identify invalid casts.
  */
 #define DMAP_RECORD(o)		     (G_TYPE_CHECK_INSTANCE_CAST ((o), \
-				      DMAP_TYPE_RECORD, DMAPRecord))
+				      DMAP_TYPE_RECORD, DmapRecord))
 /**
  * IS_DMAP_RECORD:
  * @o: Instance to check for being a %DMAP_TYPE_RECORD.
@@ -49,56 +49,54 @@ G_BEGIN_DECLS
 #define IS_DMAP_RECORD(o)	     (G_TYPE_CHECK_INSTANCE_TYPE ((o), \
 				      DMAP_TYPE_RECORD))
 /**
- * DAAP_RECORD_GET_INTERFACE:
- * @o: a #DAAPRecord instance.
+ * DMAP_RECORD_GET_INTERFACE:
+ * @o: a #DmapAvRecord instance.
  *
- * Get the class structure associated to a #DAAPRecord instance.
+ * Get the class structure associated to a #DmapAvRecord instance.
  *
  * Returns: pointer to object class structure.
  */
 #define DMAP_RECORD_GET_INTERFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), \
-				      DMAP_TYPE_RECORD, DMAPRecordIface))
-typedef struct _DMAPRecord DMAPRecord;
-typedef struct _DMAPRecordIface DMAPRecordIface;
+				      DMAP_TYPE_RECORD, DmapRecordInterface))
+typedef struct _DmapRecord DmapRecord;
+typedef struct _DmapRecordInterface DmapRecordInterface;
 
-struct _DMAPRecordIface
+struct _DmapRecordInterface
 {
 	GTypeInterface parent;
 
-	GByteArray *(*to_blob) (DMAPRecord * record);
-	gboolean   (*set_from_blob) (DMAPRecord * record, GByteArray * blob);
+	GArray *(*to_blob) (DmapRecord * record);
+	gboolean   (*set_from_blob) (DmapRecord * record, GArray * blob);
 };
 
-typedef unsigned long long bitwise;
-
 typedef enum
 {
 	DMAP_MEDIA_KIND_MUSIC = 1,
 	DMAP_MEDIA_KIND_MOVIE = 2,
 	DMAP_MEDIA_KIND_PODCAST = 32,
 	DMAP_MEDIA_KIND_TV_SHOW = 64 
-} DMAPMediaKind;
+} DmapMediaKind;
 
 GType dmap_record_get_type (void);
 
 /**
  * dmap_record_to_blob:
- * @record: A DMAPRecord.
+ * @record: A DmapRecord.
  *
- * Returns: A byte array representation of the record.
+ * Returns: (element-type guint8) (transfer container): A byte array representation of the record.
  */
-GByteArray *dmap_record_to_blob (DMAPRecord * record);
+GArray *dmap_record_to_blob (DmapRecord * record);
 
 /**
- * dmap_record_from_blob:
+ * dmap_record_set_from_blob:
  * @record: The record to set.
- * @blob:   A byte array representation of a record.
+ * @blob: (element-type guint8): A byte array representation of a record.
  *
  * Returns: True on success, else false.
  */
-gboolean dmap_record_set_from_blob (DMAPRecord * record,
-                                    GByteArray * blob);
+gboolean dmap_record_set_from_blob (DmapRecord * record,
+                                    GArray * blob);
 
-#endif /* __DMAP_RECORD_H */
+#endif /* _DMAP_RECORD_H */
 
 G_END_DECLS
