@@ -33,7 +33,7 @@
     ( (gint32)(gchar)(ch2) << 16 ) | \
     ( (gint32)(gchar)(ch3) << 24 ) ))
 
-static const DMAPContentCodeDefinition cc_defs[] = {
+static const DmapContentCodeDefinition cc_defs[] = {
 	{DMAP_RAW, 0, "", "", DMAP_TYPE_STRING},
 	{DMAP_CC_MDCL, MAKE_CONTENT_CODE ('m', 'd', 'c', 'l'),
 	 "dmap.dictionary", "mdcl", DMAP_TYPE_CONTAINER},
@@ -349,25 +349,33 @@ static const DMAPContentCodeDefinition cc_defs[] = {
 };
 
 const gchar *
-dmap_content_code_name (DMAPContentCode code)
+dmap_content_code_name (DmapContentCode code)
 {
 	return cc_defs[code - 1].name;
 }
 
-DMAPType
-dmap_content_code_dmap_type (DMAPContentCode code)
+DmapType
+dmap_content_code_dmap_type (DmapContentCode code)
 {
-	return cc_defs[code - 1].type;
+	DmapType type = DMAP_TYPE_INVALID;
+
+	if (code < sizeof cc_defs / sizeof(DmapContentCodeDefinition)) {
+		type = cc_defs[code - 1].type;
+	} else {
+		g_warning("Invalid content code: %d\n", code);
+	}
+
+	return type;
 }
 
 const gchar *
-dmap_content_code_string (DMAPContentCode code)
+dmap_content_code_string (DmapContentCode code)
 {
 	return cc_defs[code - 1].string;
 }
 
 static GType
-dmap_content_code_gtype (DMAPContentCode code)
+dmap_content_code_gtype (DmapContentCode code)
 {
 	switch (dmap_content_code_dmap_type (code)) {
 	case DMAP_TYPE_BYTE:
@@ -386,6 +394,7 @@ dmap_content_code_gtype (DMAPContentCode code)
 	case DMAP_TYPE_POINTER:
 		return G_TYPE_POINTER;
 	case DMAP_TYPE_CONTAINER:
+	case DMAP_TYPE_INVALID:
 	default:
 		return G_TYPE_NONE;
 	}
@@ -394,8 +403,8 @@ dmap_content_code_gtype (DMAPContentCode code)
 static gboolean
 dmap_structure_node_serialize (GNode * node, GByteArray * array)
 {
-	DMAPStructureItem *item = node->data;
-	DMAPType dmap_type;
+	DmapStructureItem *item = node->data;
+	DmapType dmap_type;
 	guint32 size = GINT32_TO_BE (item->size);
 
 	if (item->content_code != DMAP_RAW) {
@@ -482,6 +491,7 @@ dmap_structure_node_serialize (GNode * node, GByteArray * array)
 			break;
 		}
 	case DMAP_TYPE_CONTAINER:
+	case DMAP_TYPE_INVALID:
 	default:
 		break;
 	}
@@ -510,7 +520,7 @@ dmap_structure_serialize (GNode * structure, guint * length)
 	return data;
 }
 
-DMAPContentCode
+DmapContentCode
 dmap_content_code_read_from_buffer (const gchar * buf)
 {
 	gint32 c = MAKE_CONTENT_CODE (buf[0], buf[1], buf[2], buf[3]);
@@ -528,10 +538,10 @@ dmap_content_code_read_from_buffer (const gchar * buf)
 }
 
 static gchar *
-dmap_buffer_read_string (const gchar * buf, gssize size)
+dmap_buffer_read_string (const guint8 * buf, gsize size)
 {
-	if (g_utf8_validate (buf, size, NULL) == TRUE) {
-		return g_strndup (buf, size);
+	if (g_utf8_validate ((char *) buf, size, NULL) == TRUE) {
+		return g_strndup ((char *) buf, size);
 	} else {
 		return g_strdup ("");
 	}
@@ -539,21 +549,43 @@ dmap_buffer_read_string (const gchar * buf, gssize size)
 
 static void
 dmap_structure_parse_container_buffer (GNode * parent,
-				       const guchar * buf, gint buf_length)
+				       const guint8 * buf, gsize buf_length)
 {
 	gint l = 0;
 
 	while (l < buf_length) {
-		DMAPContentCode cc;
+		DmapContentCode cc;
 		gint codesize = 0;
-		DMAPStructureItem *item = NULL;
+		DmapStructureItem *item = NULL;
 		GNode *node = NULL;
 		GType gtype;
 
-		/* we need at least 8 bytes, 4 of content_code and 4 of size */
+		if (parent
+		 && parent->parent
+		 && ((DmapStructureItem *)parent->parent->data)
+		 && (DMAP_CC_ABGN == ((DmapStructureItem *) parent->parent->data)->content_code
+		 ||  DMAP_CC_ABAR == ((DmapStructureItem *) parent->parent->data)->content_code
+		 ||  DMAP_CC_ABAL == ((DmapStructureItem *) parent->parent->data)->content_code)) {
+			/* Assume DMAP_RAW, as grandparent is ABGN or similar. */
+			item = g_new0 (DmapStructureItem, 1);
+			item->content_code = DMAP_RAW;
+			node = g_node_new (item);
+			g_node_append (parent, node);
+			gchar *s = dmap_buffer_read_string (buf, buf_length);
+			item->size = strlen (s);
+			g_value_init (&(item->content), G_TYPE_STRING);
+			g_value_take_string (&(item->content), s);
+
+			goto done;
+		}
+
+		/*
+		 * Except in cases above, we need at least 8 bytes (4 of
+		 * content_code and 4 of size) is odd.
+		 */
 		if (buf_length - l < 8) {
 			g_debug ("Malformed response received\n");
-			return;
+			goto done;
 		}
 
 		cc = dmap_content_code_read_from_buffer ((const gchar *)
@@ -571,12 +603,12 @@ dmap_structure_parse_container_buffer (GNode * parent,
 		 * then get out before we start processing it
 		 */
 		if (codesize > buf_length - l - 4 || codesize < 0) {
-			g_debug ("Invalid codesize %d received in buf_length %d\n", codesize, buf_length);
+			g_debug ("Invalid codesize %d received in buf_length %zd\n", codesize, buf_length);
 			return;
 		}
 		l += 4;
 
-		item = g_new0 (DMAPStructureItem, 1);
+		item = g_new0 (DmapStructureItem, 1);
 		item->content_code = cc;
 		node = g_node_new (item);
 		g_node_append (parent, node);
@@ -638,9 +670,7 @@ dmap_structure_parse_container_buffer (GNode * parent,
 			}
 		case DMAP_TYPE_STRING:{
 				gchar *s =
-					dmap_buffer_read_string ((const gchar
-								  *)
-								 &(buf[l]),
+					dmap_buffer_read_string (&(buf[l]),
 								 codesize);
 
 				item->size = strlen (s);
@@ -688,16 +718,24 @@ dmap_structure_parse_container_buffer (GNode * parent,
 								       codesize);
 				break;
 			}
+		case DMAP_TYPE_INVALID:
+		default:
+			/*
+			 * Bad type should have been caught as bad content code
+			 * by dmap_content_code_read_from_buffer()
+			 */
+			g_assert_not_reached();
 		}
 
 		l += codesize;
 	}
 
+done:
 	return;
 }
 
 GNode *
-dmap_structure_parse (const gchar * buf, gint buf_length)
+dmap_structure_parse (const guint8 * buf, gsize buf_length)
 {
 	GNode *root = NULL;
 	GNode *child = NULL;
@@ -718,7 +756,7 @@ dmap_structure_parse (const gchar * buf, gint buf_length)
 
 struct NodeFinder
 {
-	DMAPContentCode code;
+	DmapContentCode code;
 	GNode *node;
 };
 
@@ -726,7 +764,7 @@ static gboolean
 gnode_find_node (GNode * node, gpointer data)
 {
 	struct NodeFinder *finder = (struct NodeFinder *) data;
-	DMAPStructureItem *item = node->data;
+	DmapStructureItem *item = node->data;
 
 	if (item->content_code == finder->code) {
 		finder->node = node;
@@ -736,8 +774,8 @@ gnode_find_node (GNode * node, gpointer data)
 	return FALSE;
 }
 
-DMAPStructureItem *
-dmap_structure_find_item (GNode * structure, DMAPContentCode code)
+DmapStructureItem *
+dmap_structure_find_item (GNode * structure, DmapContentCode code)
 {
 	GNode *node = NULL;
 
@@ -751,11 +789,11 @@ dmap_structure_find_item (GNode * structure, DMAPContentCode code)
 }
 
 GNode *
-dmap_structure_add (GNode * parent, DMAPContentCode cc, ...)
+dmap_structure_add (GNode * parent, DmapContentCode cc, ...)
 {
-	DMAPType dmap_type;
+	DmapType dmap_type;
 	GType gtype;
-	DMAPStructureItem *item;
+	DmapStructureItem *item;
 	va_list list;
 	GNode *node;
 	gchar *error = NULL;
@@ -765,7 +803,7 @@ dmap_structure_add (GNode * parent, DMAPContentCode cc, ...)
 	dmap_type = dmap_content_code_dmap_type (cc);
 	gtype = dmap_content_code_gtype (cc);
 
-	item = g_new0 (DMAPStructureItem, 1);
+	item = g_new0 (DmapStructureItem, 1);
 	item->content_code = cc;
 
 	if (gtype != G_TYPE_NONE) {
@@ -831,7 +869,7 @@ dmap_structure_add (GNode * parent, DMAPContentCode cc, ...)
 		g_node_append (parent, node);
 
 		while (parent) {
-			DMAPStructureItem *parent_item = parent->data;
+			DmapStructureItem *parent_item = parent->data;
 
 			if (cc == DMAP_RAW)
 				parent_item->size += item->size;
@@ -846,7 +884,7 @@ dmap_structure_add (GNode * parent, DMAPContentCode cc, ...)
 }
 
 GNode *
-dmap_structure_find_node (GNode * structure, DMAPContentCode code)
+dmap_structure_find_node (GNode * structure, DmapContentCode code)
 {
 	struct NodeFinder *finder;
 	GNode *node = NULL;
@@ -866,10 +904,11 @@ dmap_structure_find_node (GNode * structure, DMAPContentCode code)
 }
 
 static void
-dmap_item_free (DMAPStructureItem * item)
+dmap_item_free (DmapStructureItem * item)
 {
-	if (dmap_content_code_dmap_type (item->content_code) !=
-	    DMAP_TYPE_CONTAINER) {
+	DmapType type = dmap_content_code_dmap_type (item->content_code);
+
+	if (DMAP_TYPE_INVALID != type && DMAP_TYPE_CONTAINER != type) {
 		g_value_unset (&(item->content));
 	}
 
@@ -877,9 +916,9 @@ dmap_item_free (DMAPStructureItem * item)
 }
 
 static gboolean
-gnode_free_dmap_item (GNode * node, G_GNUC_UNUSED gpointer data)
+gnode_free_dmap_item (GNode * node, gpointer data)
 {
-	dmap_item_free ((DMAPStructureItem *) node->data);
+	dmap_item_free ((DmapStructureItem *) node->data);
 
 	return FALSE;
 }
@@ -897,7 +936,7 @@ dmap_structure_destroy (GNode * structure)
 	}
 }
 
-const DMAPContentCodeDefinition *
+const DmapContentCodeDefinition *
 dmap_content_codes (guint * number)
 {
 	*number = G_N_ELEMENTS (cc_defs);
@@ -911,22 +950,21 @@ dmap_content_code_string_as_int32 (const gchar * str)
 	union
 	{
 		gint32 i;
-		gchar str[5];
+		gchar str[4];
 	} u;
 
 	strncpy (u.str, str, 4);
-	u.str[4] = 0x00;
 
 	return g_htonl (u.i);
 }
 
 static gboolean
-print_dmap_item (GNode * node, G_GNUC_UNUSED gpointer data)
+print_dmap_item (GNode * node, gpointer data)
 {
-	DMAPStructureItem *item;
+	DmapStructureItem *item;
 	const gchar *name;
 	gchar *value;
-	guint i;
+	gint i;
 
 	for (i = 1; i < g_node_depth (node); i++) {
 		g_print ("\t");
@@ -961,7 +999,7 @@ dmap_structure_print (GNode * structure)
 guint
 dmap_structure_get_size (GNode * structure)
 {
-	DMAPStructureItem *item = (DMAPStructureItem *) structure->data;
+	DmapStructureItem *item = (DmapStructureItem *) structure->data;
 
 	g_assert (strlen(cc_defs[item->content_code].string) == 4);
 	g_assert (sizeof(item->size) == 4);
@@ -972,5 +1010,5 @@ dmap_structure_get_size (GNode * structure)
 void
 dmap_structure_increase_by_predicted_size (GNode * structure, guint size)
 {
-	((DMAPStructureItem *) structure->data)->size += size;
+	((DmapStructureItem *) structure->data)->size += size;
 }
