@@ -1,9 +1,9 @@
-#ifndef __DMAP_H
-#define __DMAP_H
+#ifndef _DMAP_H
+#define _DMAP_H
 
-#include <libdmapsharing/daap-connection.h>
-#include <libdmapsharing/daap-record.h>
-#include <libdmapsharing/daap-share.h>
+#include <libdmapsharing/dmap-av-connection.h>
+#include <libdmapsharing/dmap-av-record.h>
+#include <libdmapsharing/dmap-av-share.h>
 #include <libdmapsharing/dmap-connection.h>
 #include <libdmapsharing/dmap-container-db.h>
 #include <libdmapsharing/dmap-container-record.h>
@@ -13,15 +13,16 @@
 #include <libdmapsharing/dmap-md5.h>
 #include <libdmapsharing/dmap-mdns-browser.h>
 #include <libdmapsharing/dmap-mdns-publisher.h>
+#include <libdmapsharing/dmap-mdns-service.h>
 #include <libdmapsharing/dmap-record.h>
 #include <libdmapsharing/dmap-record-factory.h>
 #include <libdmapsharing/dmap-share.h>
 #include <libdmapsharing/dmap-utils.h>
-#include <libdmapsharing/dpap-connection.h>
-#include <libdmapsharing/dpap-record.h>
-#include <libdmapsharing/dpap-share.h>
-#include <libdmapsharing/dacp-share.h>
-#include <libdmapsharing/dacp-player.h>
-#include <libdmapsharing/dacp-connection.h>
+#include <libdmapsharing/dmap-image-connection.h>
+#include <libdmapsharing/dmap-image-record.h>
+#include <libdmapsharing/dmap-image-share.h>
+#include <libdmapsharing/dmap-control-share.h>
+#include <libdmapsharing/dmap-control-player.h>
+#include <libdmapsharing/dmap-control-connection.h>
 
-#endif /* __DMAP_H */
+#endif /* _DMAP_H */
